@@ -3,9 +3,9 @@ Tests for the generic template tags and filters.
 """
 
 from django.template import Context, Template
+from utils import TagTestCase
 
 from analytical.templatetags import analytical
-from utils import TagTestCase
 
 
 class AnalyticsTagTestCase(TagTestCase):
@@ -33,4 +33,4 @@ class AnalyticsTagTestCase(TagTestCase):
     def test_location_tags(self):
         for loc in ['head_top', 'head_bottom', 'body_top', 'body_bottom']:
             r = self.render_location_tag(loc)
-            self.assertTrue('dummy_%s' % loc in r, r)
+            assert f'dummy_{loc}' in r
