@@ -2,12 +2,13 @@
 Tests for the Clickmap template tags and filters.
 """
 
+import pytest
 from django.http import HttpRequest
 from django.template import Context
 from django.test.utils import override_settings
+from utils import TagTestCase
 
 from analytical.templatetags.clickmap import ClickmapNode
-from utils import TagTestCase
 from analytical.utils import AnalyticalException
 
 
@@ -19,19 +20,21 @@ class ClickmapTagTestCase(TagTestCase):
 
     def test_tag(self):
         r = self.render_tag('clickmap', 'clickmap')
-        self.assertTrue("tracker: '12345ABC', version:'2'};" in r, r)
+        assert "tracker: '12345ABC', version:'2'};" in r
 
     def test_node(self):
         r = ClickmapNode().render(Context({}))
-        self.assertTrue("tracker: '12345ABC', version:'2'};" in r, r)
+        assert "tracker: '12345ABC', version:'2'};" in r
 
     @override_settings(CLICKMAP_TRACKER_ID=None)
     def test_no_site_id(self):
-        self.assertRaises(AnalyticalException, ClickmapNode)
+        with pytest.raises(AnalyticalException):
+            ClickmapNode()
 
     @override_settings(CLICKMAP_TRACKER_ID='ab#c')
     def test_wrong_site_id(self):
-        self.assertRaises(AnalyticalException, ClickmapNode)
+        with pytest.raises(AnalyticalException):
+            ClickmapNode()
 
     @override_settings(ANALYTICAL_INTERNAL_IPS=['1.1.1.1'])
     def test_render_internal_ip(self):
@@ -39,6 +42,5 @@ class ClickmapTagTestCase(TagTestCase):
         req.META['REMOTE_ADDR'] = '1.1.1.1'
         context = Context({'request': req})
         r = ClickmapNode().render(context)
-        self.assertTrue(r.startswith(
-                '<!-- Clickmap disabled on internal IP address'), r)
-        self.assertTrue(r.endswith('-->'), r)
+        assert r.startswith('<!-- Clickmap disabled on internal IP address')
+        assert r.endswith('-->')
